pub type Atomic<T> = <T as AtomicPrimitive>::Atomic;Expand description
Type alias for the atomic version of a primitive type.
This mirrors the unstable core::sync::atomic::Atomic type alias.
pub type Atomic<T> = <T as AtomicPrimitive>::Atomic;Type alias for the atomic version of a primitive type.
This mirrors the unstable core::sync::atomic::Atomic type alias.